@@ -8,6 +8,13 @@ import traceback
 
 import redis
 from redisbench_admin.environments.oss_cluster import generate_cluster_redis_server_args
+
+from redisbench_admin.utils.local import check_dataset_local_requirements
+
+from redisbench_admin.run.common import (
+    dbconfig_keyspacelen_check,
+)
+
 from redisbench_admin.profilers.profilers_local import (
     local_profilers_platform_checks,
     profilers_start_if_required,
@@ -108,6 +115,7 @@ def process_self_contained_coordinator_stream(
     redis_proc_start_port=6379,
     docker_air_gap=False,
     verbose=False,
+    run_tests_with_dataset=False,
 ):
     stream_id = "n/a"
     overall_result = False
@@ -211,6 +219,31 @@ def process_self_contained_coordinator_stream(
                             restore_build_artifacts_from_test_details(
                                 build_artifacts, conn, temporary_dir, testDetails
                             )
+
+                            if "dataset" in benchmark_config["dbconfig"]:
+                                if run_tests_with_dataset is False:
+                                    logging.warning(
+                                        "Skipping test {} giving it implies dataset preload".format(
+                                            test_name
+                                        )
+                                    )
+                                    continue
+                            logging.info("Checking if there is a dataset requirement")
+                            (
+                                dataset,
+                                dataset_name,
+                                _,
+                                _,
+                            ) = check_dataset_local_requirements(
+                                benchmark_config,
+                                temporary_dir,
+                                None,
+                                "./datasets",
+                                "dbconfig",
+                                1,
+                                False,
+                            )
+
                             dso = "redis-server"
                             profilers_artifacts_matrix = []
 
@@ -285,6 +318,9 @@ def process_self_contained_coordinator_stream(
                             client_mnt_point = "/mnt/client/"
                             benchmark_tool_workdir = client_mnt_point
 
+                            logging.info(
+                                "Checking if there is a data preload_tool requirement"
+                            )
                             if "preload_tool" in benchmark_config["dbconfig"]:
                                 data_prepopulation_step(
                                     benchmark_config,
@@ -297,6 +333,14 @@ def process_self_contained_coordinator_stream(
                                     test_name,
                                 )
 
+                            logging.info(
+                                "Checking if there is a keyspace check being enforced"
+                            )
+                            dbconfig_keyspacelen_check(
+                                benchmark_config,
+                                [r],
+                            )
+
                             benchmark_tool = extract_client_tool(benchmark_config)
                             # backwards compatible
                             if benchmark_tool is None:
